Class: ActionView::ActiveScaffoldResolver
- Defined in:
- lib/active_scaffold/extensions/action_view_resolver.rb
Instance Method Summary collapse
-
#find_templates(name, prefix, partial, details, outside_app_allowed = false) ⇒ Object
standard resolvers have a base path to views and append a controller subdirectory activescaffolds view path do not have a subdir, so just remove the prefix > rails 3.2.22 uses an additional fifth parameter.
Instance Method Details
#find_templates(name, prefix, partial, details, outside_app_allowed = false) ⇒ Object
standard resolvers have a base path to views and append a controller subdirectory activescaffolds view path do not have a subdir, so just remove the prefix
rails 3.2.22 uses an additional fifth parameter
6 7 8 9 10 11 12 |
# File 'lib/active_scaffold/extensions/action_view_resolver.rb', line 6 def find_templates(name, prefix, partial, details, outside_app_allowed = false) if (::Rails::VERSION::MAJOR >= 4 && ::Rails::VERSION::MINOR > 0) || (::Rails::VERSION::MAJOR == 3 && ::Rails::VERSION::MINOR == 2 && ::Rails::VERSION::TINY >= 22) super(name,'',partial, details, outside_app_allowed) else super(name,'',partial, details) end end |